logger

package
v0.0.0-...-3a5ecfb Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 6, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func InitLogger

func InitLogger()

func L

func L() *zap.SugaredLogger

func NewWorkflowLogger

func NewWorkflowLogger(workflowName, logDir string) (*zap.SugaredLogger, error)

NewWorkflowLogger creates a dedicated logger for a specific workflow If logDir is empty, returns the global logger (stdout) If logDir is specified, creates a separate log file for the workflow

Types

This section is empty.

Jump to