Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func InitLogger ¶
func InitLogger()
func L ¶
func L() *zap.SugaredLogger
func NewWorkflowLogger ¶
func NewWorkflowLogger(workflowName, logDir string) (*zap.SugaredLogger, error)
NewWorkflowLogger creates a dedicated logger for a specific workflow If logDir is empty, returns the global logger (stdout) If logDir is specified, creates a separate log file for the workflow
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.